@@ -43,3 +43,7 @@ STARTS_WITH = "starts_with:"
 ENDS_WITH = "ends_with:"
 
 ASSERT = "assert:"
+
+USERS_FILENAME = "./tmp/users.csv"
+ANSWER_FILENAME = "./tmp/answers.csv"
+ADMIN_PASSWORD = "2lazy2change1password"
\ No newline at end of file
